(not) Just Another Biomarker (nJAB)
==========================================================

Not Just Another Biomarkers (nJAB) is a Python package for the analysis of 
clinical and omics data for the discovery of biomarkers. It's a collection of
functionality used two papers.

.. https://docutils.sourceforge.io/docs/ref/rst/directives.html#include
.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-line: 1
   :end-line: 69



You can also find an executed version on this website, see links below.

.. toctree::
   :maxdepth: 2
   :caption: Tutorials
   
   tutorial/explorative_analysis
   tutorial/log_reg

Python Package reference
------------------------

You can browse the documentation for each module of the package,
including the API reference and the source code.

.. toctree::
   :maxdepth: 2
   :caption: Python Package

   reference/modules

.. toctree::
   :hidden:
   :caption: Technical notes

   README.md
   tutorial/data/README.md

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`